@@ -65,5 +65,5 @@ def get_openapi_documentation(overrides: dict = None) -> dict:
     """
     global _openapi_documentation
     if isinstance(overrides, dict):
-        _openapi_documentation = always_merger.merge(openapi_documentation, overrides)
+        _openapi_documentation = always_merger.merge(_openapi_documentation, overrides)
     return _openapi_documentation
