@@ -4,6 +4,7 @@ from typing_extensions import Final
 import ujson as json
 from os.path import abspath, dirname, join
 
+from deepmerge import always_merger
 from aiohttp.web import Application
 from aiohttp import web
 
@@ -62,7 +63,7 @@ def generate_doc_template(
             "description": description.strip(),
             "version": api_version,
         },
-        "paths": dict,
+        "paths": defaultdict(dict),
     }
 
 
@@ -93,9 +94,11 @@ def setup_redoc(
     # api_base_url: str = "/lol",
     description: str = "OpenAPI definition",
     api_version: str = "1.0.0",
-    title: str = "Redoc API",
-    contact: str = "",
+    title: str = "ReDoc API",
+    page_title: str = "ReDoc",
+    contact: dict = None,
     openapi_info: dict = None,
+    redoc_options: dict = {},
 ):
     _redoc_url = "/{}".format(redoc_url) if not redoc_url.startswith("/") else redoc_url
     _base_redoc_url = _redoc_url.rstrip("/")
@@ -103,10 +106,7 @@ def setup_redoc(
     _openapi_def_url_json = "{}/openapi.json".format(_base_redoc_url)
     openapi_info = openapi_info
 
-    # Add API routes
-    # app.router.add_route('GET', _openapi_url, _openapi_home)
-    # app.router.add_route('GET', "{}/".format(_base_openapi_url), _openapi_home)
-    # app.router.add_route('GET', _openapi_def_url, _openapi_def)
+    # Add ReDoc routes
     app.router.add_route("GET", _redoc_url, _openapi_home)
     app.router.add_route("GET", "{}/".format(_base_redoc_url), _openapi_home)
     app.router.add_route("GET", _openapi_def_url, _openapi_def)
@@ -119,12 +119,24 @@ def setup_redoc(
     # --------------------------------------------------------------------------
     # Build templates
     # --------------------------------------------------------------------------
-    app["openapi_DEF_CONTENT"] = openapi_info
+    app["openapi_DEF_CONTENT"] = always_merger.merge(
+        openapi_info,
+        {
+            "info": {
+                "title": title,
+                "version": api_version,
+                "description": description,
+                "contact": contact,
+            }
+        },
+    )
     with open(join(STATIC_PATH, "index.html"), "r") as f:
         app["openapi_TEMPLATE_CONTENT"] = (
             f.read()
-            .replace("##openapi_CONFIG##", _openapi_def_url)
+            .replace("##OPENAPI_CONFIG##", _openapi_def_url)
             .replace("##STATIC_PATH##", "{}".format(statics_path))
+            .replace("##REDOC_OPTIONS##", json.dumps(redoc_options))
+            .replace("##PAGE_TITLE##", page_title)
         )
 
 
