@@ -5,6 +5,11 @@ from typing import Optional
 from multidict import CIMultiDict
 import yaml
 
+yaml.add_representer(
+    yaml.representer.collections.defaultdict,
+    yaml.representer.Representer.represent_dict,
+)
+
 
 def respond_with_json(
     data, status: int = 200, additional_headers: Optional[dict] = frozendict({})
@@ -76,7 +81,7 @@ def respond_with_yaml(
 
     return Response(
         status=status,
-        body=yaml.safe_dump(data),
+        body=yaml.dump(data),
         content_type="text/yaml",
         headers=_prepare_headers(additional_headers=additional_headers),
     )
